@@ -54,7 +54,7 @@ class Identifier(yaml.YAMLObject):
 
     @property
     def pascal(self):
-        return inflection.camelize(inflection.underscore(self.identifier), uppercase_first_letter=True)
+        return inflection.camelize(inflection.underscore(self.identifier), uppercase_first_letter=True).replace("_", "")
 
     @property
     def snake(self):
@@ -80,16 +80,16 @@ class Identifier(yaml.YAMLObject):
 
 
 class ResourceName:
-    def __init__(self, name: str, service):
+    def __init__(self, name: str, service=None):
         self.name = name
         self.service = service
 
     def __str__(self):
         safe = self.name.replace("${aws:region}", "us-east-1")
-        safe = safe.replace("${self:service}", self.service.service.spinal)
+        safe = safe.replace("${self:service}", (self.service.service.spinal if self.service else ""))
         safe = safe.replace("${sls:stage}", "staging")
 
-        if len(safe) > 55:
+        if len(safe) > 50:
             parts = []
             for part in self.name.split("-"):
                 if "$" in part or part == "lambda":
@@ -105,6 +105,11 @@ class ResourceName:
         return name
 
 
+class ResourceId(ResourceName):
+    def __str__(self):
+        return Identifier(super().__str__()).pascal
+
+
 class ProviderMetadata(type(YamlOrderedDict), type(abc.ABC)):
     pass
 
